==> st-progress-impl-3.0.1-20211012.090604-6-sources.jar: com/ejianc/business/progress/controller/WorkItemController.java <==
package com.ejianc.business.progress.controller;

import java.io.Serializable;

import com.ejianc.business.progress.bean.StageEntity;
import com.ejianc.business.progress.vo.StageVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.progress.bean.WorkItemEntity;
import com.ejianc.business.progress.service.IWorkItemService;
import com.ejianc.business.progress.vo.WorkItemVO;

/**
 * 工作项表(子表)
 * 
 * @author generator
 * 
 */
@Controller
@RequestMapping("workItem")
public class WorkItemController implements Serializable {
	private static final long serialVersionUID = 1L;
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    /*@Autowired
    private IOrgApi iOrgApi;*/

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改
    
    @Autowired
    private IWorkItemService service; 
    
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<WorkItemVO> saveOrUpdate(@RequestBody WorkItemVO saveorUpdateVO) {
    	WorkItemEntity entity = BeanMapper.map(saveorUpdateVO, WorkItemEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            CommonResponse<String> billCode = billCodeApi.getCodeBatchByRuleCode(BILL_CODE, InvocationInfoProxy.getTenantid());
            if(billCode.isSuccess()) {
                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	WorkItemVO vo = BeanMapper.map(entity, WorkItemVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }
    
    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<WorkItemVO> queryDetail(Long id) {
    	WorkItemEntity entity = service.selectById(id);
    	WorkItemVO vo = BeanMapper.map(entity, WorkItemVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    @RequestMapping(value = "/queryStageDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<WorkItemVO>> queryStageDetail(Long stageId)  {
        QueryParam param=new QueryParam();
        param.getParams().put("stageId",new Parameter(QueryParam.EQ,stageId));
        IPage<WorkItemEntity>pageData=service.queryPage(param);
        JSONObject page=new JSONObject();
        page.put("records",BeanMapper.mapList(pageData.getRecords(),WorkItemVO.class));
        page.put("total",pageData.getTotal());
        page.put("current",pageData.getCurrent());
        page.put("size",pageData.getSize());
        page.put("pages",pageData.getPages());


        List<WorkItemVO> stageVOS = service.queryStageDetail(stageId);
        if (CollectionUtils.isEmpty(stageVOS)){
            return CommonResponse.error("未找到对应数据");
        }
        return CommonResponse.success("查询成功",stageVOS);
    }


    //参照
    @RequestMapping(value = "/detailRef", method = RequestMethod.GET)
    @ResponseBody
    public List<WorkItemVO>detailRef(@RequestParam(value = "condition",required = false)String condition){
        Map<String,Object> conditionMap=JSONObject.parseObject(condition,Map.class);
        if (null!=conditionMap.get("stageId")){
            Long stageId = Long.valueOf(conditionMap.get("stageId").toString());
            return service.detailRef(stageId);
        }
        return null;
    }
    
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<WorkItemVO> vos) {
        service.removeByIds(vos.stream().map(WorkItemVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }
    
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<WorkItemVO>>queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        // param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        IPage<WorkItemEntity> page = service.queryPage(param,false);
        IPage<WorkItemVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), WorkItemVO.class));



        return CommonResponse.success("查询列表数据成功！", pageData);

    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
       // param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<WorkItemEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("WorkItem-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refWorkItemData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<WorkItemVO>> refWorkItemData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        param.getFuzzyFields().add("code");
        param.getFuzzyFields().add("stageName");
        param.getFuzzyFields().add("sort");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<WorkItemEntity> page = service.queryPage(param,false);
        IPage<WorkItemVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), WorkItemVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> st-progress-impl-3.0.1-20211013.085400-9-sources.jar: com/ejianc/business/progress/controller/WorkItemController.java <==
package com.ejianc.business.progress.controller;

import java.io.Serializable;

import com.ejianc.business.progress.bean.StageEntity;
import com.ejianc.business.progress.vo.StageVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.progress.bean.WorkItemEntity;
import com.ejianc.business.progress.service.IWorkItemService;
import com.ejianc.business.progress.vo.WorkItemVO;

/**
 * 工作项表(子表)
 * 
 * @author generator
 * 
 */
@Controller
@RequestMapping("workItem")
public class WorkItemController implements Serializable {
	private static final long serialVersionUID = 1L;
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    /*@Autowired
    private IOrgApi iOrgApi;*/

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改
    
    @Autowired
    private IWorkItemService service; 
    
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<WorkItemVO> saveOrUpdate(@RequestBody WorkItemVO saveorUpdateVO) {
    	WorkItemEntity entity = BeanMapper.map(saveorUpdateVO, WorkItemEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            CommonResponse<String> billCode = billCodeApi.getCodeBatchByRuleCode(BILL_CODE, InvocationInfoProxy.getTenantid());
            if(billCode.isSuccess()) {
                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	WorkItemVO vo = BeanMapper.map(entity, WorkItemVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }
    
    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<WorkItemVO> queryDetail(Long id) {
    	WorkItemEntity entity = service.selectById(id);
    	WorkItemVO vo = BeanMapper.map(entity, WorkItemVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    @RequestMapping(value = "/queryStageDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<WorkItemVO>> queryStageDetail(Long stageId)  {
        List<WorkItemVO> stageVOS = service.queryStageDetail(stageId);
        if (CollectionUtils.isEmpty(stageVOS)){
            return CommonResponse.error("未找到对应数据");
        }
        return CommonResponse.success("查询成功",stageVOS);
    }


    //参照
    @RequestMapping(value = "/detailRef", method = RequestMethod.GET)
    @ResponseBody
    public List<WorkItemVO>detailRef(@RequestParam(value = "condition",required = false)String condition){
        Map<String,Object> conditionMap=JSONObject.parseObject(condition,Map.class);
        if (null!=conditionMap.get("stageId")){
            Long stageId = Long.valueOf(conditionMap.get("stageId").toString());
            return service.detailRef(stageId);
        }
        return null;
    }
    
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     *//*
    @RequestMapping(value = "/delete", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> delete(  Long id) {
        //先查询下main有没有子节点
        List<WorkItemVO> children = service.queryListByPid(id);
        if (children!=null&&children.size()>0){
            return CommonResponse.error("该阶段下有子节点,不允许删除");
        }

        return CommonResponse.success("删除成功！");
    }*/

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<StageVO> vos) {
        service.removeByIds(vos.stream().map(StageVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }
    
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<WorkItemVO>>queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        // param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        IPage<WorkItemEntity> page = service.queryPage(param,false);
        IPage<WorkItemVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), WorkItemVO.class));



        return CommonResponse.success("查询列表数据成功！", pageData);

    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
       // param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<WorkItemEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("WorkItem-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refWorkItemData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<WorkItemVO>> refWorkItemData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        param.getFuzzyFields().add("code");
        param.getFuzzyFields().add("stageName");
        param.getFuzzyFields().add("sort");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<WorkItemEntity> page = service.queryPage(param,false);
        IPage<WorkItemVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), WorkItemVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
